.github
README.md
api
cache
classes
config.TEMPLATE.inc.php
config.inc.php
controllers
cypress.json
dbscripts
docs
favicon.ico
index.php
js
lib
locale
pages
plugins
public
registry
robots.txt
schemas
styles
templates
tools